# Global Prime Pay SDK





more info at https://doc.gbprimepay.com
for python docs see https://thanakijwanavit.github.io/globalPrimePay/

## Install

`pip install globalPrimePay`

## How to use

1. Get appropriate secret and public key
2. go through get started
3. python docs [here](https://thanakijwanavit.github.io/globalPrimePay/)
